@@ -44,11 +44,11 @@
 #include <gconf/gconf-client.h>
 #include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-url.h>
+#include <lunar/lunar.h>
 
 #ifdef HAVE_LIBECAL
 #include "calendar-client.h"
 #endif
-#include "gtkchinesecalendar.h"
 
 #define CLOCK_ICON "lunar-applet"
 #define INTERNETSECOND (864)
@@ -1125,7 +1125,7 @@ mark_day_on_calendar (CalendarClient *client,
 		      guint           day,
 		      ClockData      *cd)
 {
-        gtk_chinese_calendar_mark_day (GTK_CHINESE_CALENDAR (cd->calendar), day);
+        lunar_calendar_mark_day (LUNAR_CALENDAR (cd->calendar), day);
 }
 
 static void
@@ -1135,7 +1135,7 @@ handle_appointments_changed (ClockData *cd)
         guint   year, month, day;
 
         if (cd->calendar) {
-                gtk_chinese_calendar_clear_marks (GTK_CHINESE_CALENDAR (cd->calendar));
+                lunar_calendar_clear_marks (LUNAR_CALENDAR (cd->calendar));
 
                 calendar_client_foreach_appointment_day (cd->client,
                                                          (CalendarDayIter) mark_day_on_calendar,
@@ -1268,7 +1268,7 @@ calendar_day_activated (ClockData   *cd,
 	char         *command_line;
 	GError       *error;
 
-	gtk_chinese_calendar_get_date (GTK_CHINESE_CALENDAR (cd->calendar),
+	lunar_calendar_get_date (LUNAR_CALENDAR (cd->calendar),
 			       &year, &month, &day);
 
 	command_line = g_strdup_printf ("evolution "
@@ -1291,7 +1291,7 @@ calendar_day_selected (ClockData *cd)
 {
         guint day;
 
-        gtk_chinese_calendar_get_date (GTK_CHINESE_CALENDAR (cd->calendar), NULL, NULL, &day);
+        lunar_calendar_get_date (LUNAR_CALENDAR (cd->calendar), NULL, NULL, &day);
 
         calendar_client_select_day (cd->client, day);
 
@@ -1304,7 +1304,7 @@ calendar_month_selected (ClockData *cd)
 {
         guint year, month;
 
-        gtk_chinese_calendar_get_date (GTK_CHINESE_CALENDAR (cd->calendar), &year, &month, NULL);
+        lunar_calendar_get_date (LUNAR_CALENDAR (cd->calendar), &year, &month, NULL);
 
         calendar_client_select_month (cd->client, month, year);
 
@@ -1397,7 +1397,7 @@ add_appointments_and_tasks (ClockData *cd,
                                           G_CALLBACK (handle_appointments_changed), cd);
         }
 
-        gtk_chinese_calendar_get_date (GTK_CHINESE_CALENDAR (cd->calendar), &year, &month, &day);
+        lunar_calendar_get_date (LUNAR_CALENDAR (cd->calendar), &year, &month, &day);
 
         calendar_client_select_day   (cd->client, day);
         calendar_client_select_month (cd->client, month, year);
@@ -1450,27 +1450,27 @@ create_calendar (ClockData *cd,
 	g_signal_connect (window, "key_press_event",
 			  G_CALLBACK (close_on_escape), cd);
 			
-	cd->calendar = gtk_chinese_calendar_new ();
+	cd->calendar = lunar_calendar_new ();
         g_object_add_weak_pointer (G_OBJECT (cd->calendar),
                                    (gpointer *) &cd->calendar);
 
-	options = gtk_chinese_calendar_get_display_options (GTK_CHINESE_CALENDAR (cd->calendar));
+	options = lunar_calendar_get_display_options (LUNAR_CALENDAR (cd->calendar));
 	if (cd->showweek)
-		options |= GTK_CHINESE_CALENDAR_SHOW_WEEK_NUMBERS;
+		options |= LUNAR_CALENDAR_SHOW_WEEK_NUMBERS;
 	if (cd->showlunardate)
-            options |= GTK_CHINESE_CALENDAR_SHOW_LUNAR_DATE;
+            options |= LUNAR_CALENDAR_SHOW_LUNAR;
         else
-            options &= ~GTK_CHINESE_CALENDAR_SHOW_LUNAR_DATE;
-	gtk_chinese_calendar_set_display_options (GTK_CHINESE_CALENDAR (cd->calendar), options);
+            options &= ~LUNAR_CALENDAR_SHOW_LUNAR;
+	lunar_calendar_set_display_options (LUNAR_CALENDAR (cd->calendar), options);
 
 	if (cd->gmt_time)
 		tm = gmtime (&cd->current_time);
 	else
 		tm = localtime (&cd->current_time);
-        gtk_chinese_calendar_select_month (GTK_CHINESE_CALENDAR (cd->calendar),
+        lunar_calendar_select_month (LUNAR_CALENDAR (cd->calendar),
                                    tm->tm_mon,
                                    tm->tm_year + 1900);
-        gtk_chinese_calendar_select_day (GTK_CHINESE_CALENDAR (cd->calendar), tm->tm_mday);
+        lunar_calendar_select_day (LUNAR_CALENDAR (cd->calendar), tm->tm_mday);
 
 	switch (cd->orient) {
         case PANEL_APPLET_ORIENT_UP:
@@ -2196,14 +2196,14 @@ show_week_changed (GConfClient  *client,
 	clock->showweek = (value != 0);
 
 	if (clock->calendar_popup != NULL) {
-		options = gtk_chinese_calendar_get_display_options (GTK_CHINESE_CALENDAR (clock->calendar));
+		options = lunar_calendar_get_display_options (LUNAR_CALENDAR (clock->calendar));
 
 		if (clock->showweek)
-			options |= GTK_CHINESE_CALENDAR_SHOW_WEEK_NUMBERS;
+			options |= LUNAR_CALENDAR_SHOW_WEEK_NUMBERS;
 		else
-			options &= ~(GTK_CHINESE_CALENDAR_SHOW_WEEK_NUMBERS);
+			options &= ~(LUNAR_CALENDAR_SHOW_WEEK_NUMBERS);
 
-		gtk_chinese_calendar_set_display_options (GTK_CHINESE_CALENDAR (clock->calendar),
+		lunar_calendar_set_display_options (LUNAR_CALENDAR (clock->calendar),
 						  options);
 
                 position_calendar_popup (clock, clock->calendar_popup,
@@ -2906,6 +2906,7 @@ clock_factory (PanelApplet *applet,
 	       gpointer     data)
 {
 	gboolean retval = FALSE;
+    lunar_init(NULL, NULL);
 
 	if (!strcmp (iid, "OAFIID:GNOME_LunarApplet"))
 		retval = fill_clock_applet (applet);
